---
title: Survivor
description: Represents a survivor layer in a cell.
---

## Attributes

| Attribute | Type | Description                         |
|-----------|------|-------------------------------------|
| `health`  | `int` | The amount of health of the survivor. |
